@@ -1,4 +1,4 @@
-/*
+﻿/*
     This file is part of the KDE project
     SPDX-FileCopyrightText: 1999-2011 David Faure <faure@kde.org>
     SPDX-FileCopyrightText: 2001 Carsten Pfeiffer <pfeiffer@kde.org>
@@ -581,7 +581,7 @@ KFileItem::KFileItem(mode_t mode, mode_t permissions, const QUrl &url, bool dela
 KFileItem::KFileItem(const QUrl &url, const QString &mimeType, mode_t mode)
     : d(new KFileItemPrivate(KIO::UDSEntry(), mode, KFileItem::Unknown, url, false, false, KFileItem::NormalMimeTypeDetermination))
 {
-    d->m_bMimeTypeKnown = !mimeType.isEmpty();
+    d->m_bMimeTypeKnown = !mimeType.simplified().isEmpty();
     if (d->m_bMimeTypeKnown) {
         QMimeDatabase db;
         d->m_mimeType = db.mimeTypeForName(mimeType);
@@ -1288,6 +1288,10 @@ bool KFileItem::isDir() const
         return false;
     }
 
+    if (d->m_bMimeTypeKnown && d->m_mimeType.isValid()) {
+        return d->m_mimeType.inherits(QStringLiteral("inode/directory"));
+    }
+
     if (d->m_bSkipMimeTypeFromContent) {
         return false;
     }
