@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-                  2000-2014 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2014 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MKPATHJOB_H
@@ -23,12 +11,11 @@
 
 #include <QUrl>
 
-#include "kiocore_export.h"
 #include "job_base.h"
+#include "kiocore_export.h"
 
 namespace KIO
 {
-
 class MkpathJobPrivate;
 /**
  * @class KIO::MkpathJob mkpathjob.h <KIO/MkpathJob>
@@ -44,7 +31,7 @@ class KIOCORE_EXPORT MkpathJob : public Job
     Q_OBJECT
 
 public:
-    ~MkpathJob() Q_DECL_OVERRIDE;
+    ~MkpathJob() override;
 
 Q_SIGNALS:
     /**
@@ -53,7 +40,7 @@ Q_SIGNALS:
     void directoryCreated(const QUrl &url);
 
 protected Q_SLOTS:
-    void slotResult(KJob *job) Q_DECL_OVERRIDE;
+    void slotResult(KJob *job) override;
 
 protected:
     MkpathJob(MkpathJobPrivate &dd);
