@@ -15,7 +15,6 @@
 
 namespace KIO
 {
-
 class StatJobPrivate;
 /**
  * @class KIO::StatJob statjob.h <KIO/StatJob>
@@ -25,7 +24,6 @@ class StatJobPrivate;
  */
 class KIOCORE_EXPORT StatJob : public SimpleJob
 {
-
     Q_OBJECT
 
 public:
@@ -150,6 +148,7 @@ Q_SIGNALS:
 protected Q_SLOTS:
     void slotFinished() override;
     void slotMetaData(const KIO::MetaData &_metaData) override;
+
 protected:
     StatJob(StatJobPrivate &dd);
 
@@ -192,8 +191,8 @@ KIOCORE_EXPORT StatJob *stat(const QUrl &url, JobFlags flags = DefaultFlags);
  * @return the job handling the operation.
  * @since 5.69
  */
-KIOCORE_EXPORT StatJob *statDetails(const QUrl &url, KIO::StatJob::StatSide side,
-                             KIO::StatDetails details = KIO::StatDefaultDetails, JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT StatJob *
+statDetails(const QUrl &url, KIO::StatJob::StatSide side, KIO::StatDetails details = KIO::StatDefaultDetails, JobFlags flags = DefaultFlags);
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 69)
 /**
@@ -224,9 +223,9 @@ KIOCORE_EXPORT StatJob *statDetails(const QUrl &url, KIO::StatJob::StatSide side
  * @return the job handling the operation.
  * @deprecated since 5.69, use statDetails(const QUrl &, KIO::StatJob::StatSide, KIO::StatDetails, JobFlags)
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(5, 69, "Use KIO::statDetails(const QUrl &, KIO::StatJob::StatSide, KIO::StatDetails, JobFlags)")
-KIOCORE_EXPORT StatJob *stat(const QUrl &url, KIO::StatJob::StatSide side,
-                             short int details, JobFlags flags = DefaultFlags);
+StatJob *stat(const QUrl &url, KIO::StatJob::StatSide side, short int details, JobFlags flags = DefaultFlags);
 #endif
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 69)
@@ -236,8 +235,9 @@ KIOCORE_EXPORT StatJob *stat(const QUrl &url, KIO::StatJob::StatSide side,
  * @since 5.69
  * @deprecated since 5.69, use directly KIO::StatDetails
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(5, 69, "Use directly KIO::StatDetails")
-KIOCORE_EXPORT KIO::StatDetails detailsToStatDetails(int details);
+KIO::StatDetails detailsToStatDetails(int details);
 #endif
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 0)
@@ -269,9 +269,9 @@ KIOCORE_EXPORT KIO::StatDetails detailsToStatDetails(int details);
  * @return the job handling the operation.
  * @deprecated Since 4.0, use stat(const QUrl &, KIO::StatJob::StatSide, short int, JobFlags)
  */
+KIOCORE_EXPORT
 KIOCORE_DEPRECATED_VERSION(4, 0, "Use KIO::stat(const QUrl &, KIO::StatJob::StatSide, short int, JobFlags)")
-KIOCORE_EXPORT StatJob *stat(const QUrl &url, bool sideIsSource,
-                             short int details, JobFlags flags = DefaultFlags);
+StatJob *stat(const QUrl &url, bool sideIsSource, short int details, JobFlags flags = DefaultFlags);
 #endif
 
 /**
