@@ -93,7 +93,7 @@ public:
         QString errorStr;
         // encode the two-dimensional numeric error list using '\n' and '\t' as outer and inner separators
         for (const QSslCertificate &cert : peerCertificateChain) {
-            for (const QSslError &error : qAsConst(sslErrors)) {
+            for (const QSslError &error : std::as_const(sslErrors)) {
                 if (error.certificate() == cert) {
                     errorStr += QString::number(static_cast<int>(error.error())) + QLatin1Char('\t');
                 }
@@ -181,10 +181,7 @@ TCPSlaveBase::TCPSlaveBase(const QByteArray &protocol, const QByteArray &poolSoc
     d->socket.setReadBufferSize(14680064);
 }
 
-TCPSlaveBase::~TCPSlaveBase()
-{
-    delete d;
-}
+TCPSlaveBase::~TCPSlaveBase() = default;
 
 ssize_t TCPSlaveBase::write(const char *data, ssize_t len)
 {
@@ -527,7 +524,7 @@ TCPSlaveBase::SslResult TCPSlaveBase::verifyServerCertificate()
     //### We don't ask to permanently reject the certificate
 
     QString message = i18n("The server failed the authenticity check (%1).\n\n", d->host);
-    for (const QSslError &err : qAsConst(d->sslErrors)) {
+    for (const QSslError &err : std::as_const(d->sslErrors)) {
         message += err.errorString() + QLatin1Char('\n');
     }
     message = message.trimmed();
