@@ -258,8 +258,8 @@ FilterOptions::FilterOptions(QWidget *parent, const QVariantList &args)
     connect(m_dlg.cbUseSelectedShortcutsOnly, &QAbstractButton::toggled, this, &FilterOptions::markAsChanged);
 
     connect(m_providersModel, &ProvidersModel::dataModified, this, &FilterOptions::markAsChanged);
-    connect(m_dlg.cmbDefaultEngine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &FilterOptions::markAsChanged);
-    connect(m_dlg.cmbDelimiter, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &FilterOptions::markAsChanged);
+    connect(m_dlg.cmbDefaultEngine, qOverload<int>(&QComboBox::currentIndexChanged), this, &FilterOptions::markAsChanged);
+    connect(m_dlg.cmbDelimiter, qOverload<int>(&QComboBox::currentIndexChanged), this, &FilterOptions::markAsChanged);
 
     connect(m_dlg.pbNew, &QAbstractButton::clicked, this, &FilterOptions::addSearchProvider);
     connect(m_dlg.pbDelete, &QAbstractButton::clicked, this, &FilterOptions::deleteSearchProvider);
@@ -312,7 +312,7 @@ void FilterOptions::load()
 
     int defaultProviderIndex = providers.size(); // default is "None", it is last in the list
 
-    for (SearchProvider *provider : qAsConst(providers)) {
+    for (SearchProvider *provider : std::as_const(providers)) {
         if (defaultSearchEngine == provider->desktopEntryName()) {
             defaultProviderIndex = providers.indexOf(provider);
             break;
@@ -355,7 +355,6 @@ void FilterOptions::save()
     group.writeEntry("PreferredWebShortcuts", m_providersModel->favoriteEngines());
     group.writeEntry("UsePreferredWebShortcutsOnly", m_dlg.cbUseSelectedShortcutsOnly->isChecked());
 
-    int changedProviderCount = 0;
     const QList<SearchProvider *> providers = m_providersModel->providers();
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices5/searchproviders/");
 
@@ -364,12 +363,9 @@ void FilterOptions::save()
             continue;
         }
 
-        changedProviderCount++;
-
         KConfig _service(path + provider->desktopEntryName() + QLatin1String(".desktop"), KConfig::SimpleConfig);
         KConfigGroup service(&_service, "Desktop Entry");
         service.writeEntry("Type", "Service");
-        service.writeEntry("X-KDE-ServiceTypes", "SearchProvider");
         service.writeEntry("Name", provider->name());
         service.writeEntry("Query", provider->query());
         service.writeEntry("Keys", provider->keys());
@@ -379,7 +375,7 @@ void FilterOptions::save()
 
     const QStringList servicesDirs =
         QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5/searchproviders/"), QStandardPaths::LocateDirectory);
-    for (const QString &providerName : qAsConst(m_deletedProviders)) {
+    for (const QString &providerName : std::as_const(m_deletedProviders)) {
         QStringList matches;
         for (const QString &dir : servicesDirs) {
             QString current = dir + QLatin1Char('/') + providerName + QLatin1String(".desktop");
@@ -393,8 +389,6 @@ void FilterOptions::save()
             continue;
         }
 
-        changedProviderCount++;
-
         if (matches.size() == 1 && matches.first().startsWith(path)) {
             // If only the local copy existed, unlink it
             // TODO: error handling
@@ -405,7 +399,6 @@ void FilterOptions::save()
         KConfig _service(path + providerName + QLatin1String(".desktop"), KConfig::SimpleConfig);
         KConfigGroup service(&_service, "Desktop Entry");
         service.writeEntry("Type", "Service");
-        service.writeEntry("X-KDE-ServiceTypes", "SearchProvider");
         service.writeEntry("Hidden", true);
     }
 
@@ -416,11 +409,6 @@ void FilterOptions::save()
     // Update filters in running applications...
     QDBusMessage msg = QDBusMessage::createSignal(QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"), QStringLiteral("configure"));
     QDBusConnection::sessionBus().send(msg);
-
-    // If the providers changed, tell sycoca to rebuild its database...
-    if (changedProviderCount) {
-        KBuildSycocaProgressDialog::rebuildKSycoca(this);
-    }
 }
 
 void FilterOptions::defaults()
